@@ -1,16 +1,15 @@
 <?php
 // require_once 'Psr/Cache/autoload.php'; (already required by Cache)
 // require_once 'Psr/Container/autoload.php'; (already required by Service)
+// require_once 'Psr/EventDispatcher/autoload.php'; (already required by EventDispatcher)
 
-require_once 'Symfony/Contracts/Cache/autoload.php';
-require_once 'Symfony/Contracts/EventDispatcher/autoload.php';
-require_once 'Symfony/Contracts/HttpClient/autoload.php';
-require_once 'Symfony/Contracts/Service/autoload.php';
-require_once 'Symfony/Contracts/Translation/autoload.php';
+require_once __DIR__ . '/Cache/autoload.php';
+require_once __DIR__ . '/Deprecation/autoload.php';
+require_once __DIR__ . '/EventDispatcher/autoload.php';
+require_once __DIR__ . '/HttpClient/autoload.php';
+require_once __DIR__ . '/Service/autoload.php';
+require_once __DIR__ . '/Translation/autoload.php';
 
-// if (stream_resolve_include_path('Psr/EventDispatcher/autoload.php')){ (already suggested by EventDispatcher)
-//     include_once 'Psr/EventDispatcher/autoload.php';
-// }
 // if (stream_resolve_include_path('Symfony/Component/Cache/autoload.php')){ (already suggested by Cache)
 //     include_once 'Symfony/Component/Cache/autoload.php';
 // }
